"""
**Foliant** is a documentation generator that builds PDF, Docx, and TeX output
from a single Markdown source. It also uploads Docx files to Google Drive
as Google Documents.
"""

__name__ = "foliant"
__description__ = "Documentation generator that builds PDF, Docx, and TeX from\
    a single Markdown source."
__author__ = "Konstantin Molchanov"
__author_email__ = "moigagoo@live.com"
__version__ = "0.3.5"
